| tessellation_adjacency_matrix | R Documentation |
This function deals with spatial data having a point-level geometry domain. It converts the spatial proximity into an adjacency matrix based on Voronoi tessellation or Delaunay triangulation.
tessellation_adjacency_matrix(geometry_domain)
geometry_domain |
n by d matrix (NA not allowed) of geographical coordinates for n points in d-dimensional space. |
A matrix with 0-1 values indicating the adjacency between the n input points.
ShengLi Tzeng and Hao-Yun Hsu.
Gallier, J. (2011). Dirichlet–Voronoi Diagrams and Delaunay Triangulations. In Geometric Methods and Applications (pp. 301-319). Springer, New York, NY.
if( require(fields) & require(alphahull) ) {
pts <- ChicagoO3$x
rownames(pts) <- LETTERS[1:20]
Vcells <- delvor(pts)
plot(Vcells,wlines='vor',pch='.')
text(pts,rownames(pts))
Amat <- tessellation_adjacency_matrix(pts)
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.