Learn R Programming

HCV (version 1.2.0)

tessellation_adjacency_matrix: Adjacency Matrix from Tessellation

Description

This function deals with spatial data having a point-level geometry domain. It converts the spatial proximity into an adjacency matrix based on Voronoi tessellation or Delaunay triangulation.

Usage

tessellation_adjacency_matrix(geometry_domain)

Arguments

geometry_domain

n by d matrix (NA not allowed) of geographical coordinates for n points in d-dimensional space.

Value

A matrix with 0-1 values indicating the adjacency between the n input points.

References

Gallier, J. (2011). Dirichlet<U+2013>Voronoi Diagrams and Delaunay Triangulations. In Geometric Methods and Applications (pp. 301-319). Springer, New York, NY.

Examples

Run this code
# NOT RUN {
if( require(fields) & require(alphahull) ) {
pts <- ChicagoO3$x
rownames(pts) <- LETTERS[1:20]
Vcells <- delvor(pts)
plot(Vcells,wlines='vor',pch='.')
text(pts,rownames(pts))
Amat <- tessellation_adjacency_matrix(pts)  
}
# }

Run the code above in your browser using DataLab